@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2020-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2020-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -192,7 +192,7 @@ void testing_gels_bad_arg()
         // size_t size_W;
         // hipsolver_gels_bufferSize(
         //     API, handle, m, n, nrhs, dA.data(), lda, dB.data(), ldb, dX.data(), ldx, &size_W);
-        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, 1);
         // if(size_W)
         //     CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -232,7 +232,7 @@ void testing_gels_bad_arg()
         size_t size_W;
         hipsolver_gels_bufferSize(
             API, handle, m, n, nrhs, dA.data(), lda, dB.data(), ldb, dX.data(), ldx, &size_W);
-        device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        device_strided_batch_vector<T> dWork(size_W, 1, size_W, 1);
         if(size_W)
             CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -386,7 +386,7 @@ void gels_getError(const hipsolverHandle_t handle,
     // CPU lapack
     for(int b = 0; b < bc; ++b)
     {
-        cblas_gels<T>(
+        cpu_gels(
             HIPSOLVER_OP_N, m, n, nrhs, hA[b], lda, hX[b], max(m, n), hW.data(), sizeW, hInfo[b]);
     }
 
@@ -476,17 +476,17 @@ void gels_getPerfData(const hipsolverHandle_t handle,
         *cpu_time_used = get_time_us_no_sync();
         for(int b = 0; b < bc; ++b)
         {
-            cblas_gels<T>(HIPSOLVER_OP_N,
-                          m,
-                          n,
-                          nrhs,
-                          hA[b],
-                          lda,
-                          hX[b],
-                          max(m, n),
-                          hW.data(),
-                          sizeW,
-                          hInfo[b]);
+            cpu_gels(HIPSOLVER_OP_N,
+                     m,
+                     n,
+                     nrhs,
+                     hA[b],
+                     lda,
+                     hX[b],
+                     max(m, n),
+                     hW.data(),
+                     sizeW,
+                     hInfo[b]);
         }
         *cpu_time_used = get_time_us_no_sync() - *cpu_time_used;
     }
@@ -681,7 +681,7 @@ void testing_gels(Arguments& argus)
         // device_batch_vector<T>           dB(size_B, 1, bc);
         // device_batch_vector<T>           dX(size_X, 1, bc);
         // device_strided_batch_vector<int> dInfo(1, 1, 1, bc);
-        // device_strided_batch_vector<T>   dWork(size_W, 1, size_W, bc);
+        // device_strided_batch_vector<T>   dWork(size_W, 1, size_W, 1); // size_W accounts for bc
         // if(size_A)
         //     CHECK_HIP_ERROR(dA.memcheck());
         // if(size_B)
@@ -766,7 +766,7 @@ void testing_gels(Arguments& argus)
         device_strided_batch_vector<T>   dB(size_B, 1, stB, bc);
         device_strided_batch_vector<T>   dX(size_X, 1, stX, bc);
         device_strided_batch_vector<int> dInfo(1, 1, 1, bc);
-        device_strided_batch_vector<T>   dWork(size_W, 1, size_W, bc);
+        device_strided_batch_vector<T>   dWork(size_W, 1, size_W, 1); // size_W accounts for bc
         if(size_A)
             CHECK_HIP_ERROR(dA.memcheck());
         if(size_B)
