@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2020-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2020-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -322,7 +322,7 @@ void testing_gesvd_bad_arg()
 
         // int size_W;
         // hipsolver_gesvd_bufferSize(API, handle, left_svect, right_svect, m, n, dA.data(), lda, &size_W);
-        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, 1);
         // if(size_W)
         //     CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -350,7 +350,7 @@ void testing_gesvd_bad_arg()
         int size_W;
         hipsolver_gesvd_bufferSize(
             API, handle, left_svect, right_svect, m, n, dA.data(), lda, &size_W);
-        device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        device_strided_batch_vector<T> dWork(size_W, 1, size_W, 1);
         if(size_W)
             CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -533,21 +533,21 @@ void gesvd_getError(const hipsolverHandle_t handle,
 
     // CPU lapack
     for(int b = 0; b < bc; ++b)
-        cblas_gesvd<T>(left_svect,
-                       right_svect,
-                       m,
-                       n,
-                       hA[b],
-                       lda,
-                       hS[b],
-                       hU[b],
-                       ldu,
-                       hV[b],
-                       ldv,
-                       hWork.data(),
-                       size_W,
-                       hE[b],
-                       hinfo[b]);
+        cpu_gesvd(left_svect,
+                  right_svect,
+                  m,
+                  n,
+                  hA[b],
+                  lda,
+                  hS[b],
+                  hU[b],
+                  ldu,
+                  hV[b],
+                  ldv,
+                  hWork.data(),
+                  size_W,
+                  hE[b],
+                  hinfo[b]);
 
     // GPU lapack
     CHECK_ROCBLAS_ERROR(hipsolver_gesvd(API,
@@ -709,21 +709,21 @@ void gesvd_getPerfData(const hipsolverHandle_t handle,
         // cpu-lapack performance (only if not in perf mode)
         *cpu_time_used = get_time_us_no_sync();
         for(int b = 0; b < bc; ++b)
-            cblas_gesvd<T>(left_svect,
-                           right_svect,
-                           m,
-                           n,
-                           hA[b],
-                           lda,
-                           hS[b],
-                           hU[b],
-                           ldu,
-                           hV[b],
-                           ldv,
-                           hWork.data(),
-                           size_W,
-                           hE[b],
-                           hinfo[b]);
+            cpu_gesvd(left_svect,
+                      right_svect,
+                      m,
+                      n,
+                      hA[b],
+                      lda,
+                      hS[b],
+                      hU[b],
+                      ldu,
+                      hV[b],
+                      ldv,
+                      hWork.data(),
+                      size_W,
+                      hE[b],
+                      hinfo[b]);
         *cpu_time_used = get_time_us_no_sync() - *cpu_time_used;
     }
 
@@ -1089,7 +1089,7 @@ void testing_gesvd(Arguments& argus)
     device_strided_batch_vector<int> dinfo(1, 1, 1, bc);
     device_strided_batch_vector<T>   dVT(size_VT, 1, stVT, bc);
     device_strided_batch_vector<T>   dUT(size_UT, 1, stUT, bc);
-    device_strided_batch_vector<T>   dWork(size_W, 1, size_W, bc);
+    device_strided_batch_vector<T>   dWork(size_W, 1, size_W, 1); // size_W accounts for bc
     if(size_VT)
         CHECK_HIP_ERROR(dVT.memcheck());
     if(size_UT)
